# Changelog

##v2.1.0

* change can config env variable to `ICU_CAN_CHANNEL` and `ICU_CAN_INTERFACE`

##v2.0.0

* update protocol to version 12
* add generic device parameters


##v1.0.0

* update can protocol to version 11.
* update tooling to work with can protocol 11
* add mqtt interface to mock.


##v0.5.0

* add `icu inspect`
* fix `icu output` bug using wrong message
